@@ -5,9 +5,9 @@ namespace plugin { namespace Demo_Rot13 { Plugin plugin; } }
 
 using namespace plugin::Demo_Rot13;
 
-plugin::Configuration Plugin::Configure()
+zeek::plugin::Configuration Plugin::Configure()
 	{
-	plugin::Configuration config;
+	zeek::plugin::Configuration config;
 	config.name = "Demo::Rot13";
 	config.description = "<Insert description>";
 	config.version.major = 0;
